thesaurus_test
==============

.. image:: https://img.shields.io/pypi/v/thesaurus_test.svg
    :target: https://pypi.python.org/pypi/thesaurus_test/
    :alt: Latest PyPI version
 

.. image:: https://travis-ci.com/github/gniu25/package.png
   :target: https://travis-ci.com/github/gniu25/package
   :alt: Latest Travis CI build status

A package to help analysts extract key terms

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`thesaurus_test` was written by `RCDC <guiran.niu@nih.gov>`_.
